@@ -94,7 +94,7 @@ struct CreateInviteFields {
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token".to_owned());
 ///
-/// let channel_id = ChannelId(123);
+/// let channel_id = ChannelId::new(123).expect("non zero");
 /// let invite = client
 ///     .create_invite(channel_id)
 ///     .max_uses(3)?
@@ -148,7 +148,7 @@ impl<'a> CreateInvite<'a> {
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let client = Client::new(env::var("DISCORD_TOKEN")?);
-    /// let invite = client.create_invite(ChannelId(1))
+    /// let invite = client.create_invite(ChannelId::new(1).expect("non zero"))
     ///     .max_age(60 * 60)?
     ///     .exec()
     ///     .await?
@@ -186,7 +186,7 @@ impl<'a> CreateInvite<'a> {
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let client = Client::new(env::var("DISCORD_TOKEN")?);
-    /// let invite = client.create_invite(ChannelId(1))
+    /// let invite = client.create_invite(ChannelId::new(1).expect("non zero"))
     ///     .max_uses(5)?
     ///     .exec()
     ///     .await?
@@ -259,7 +259,7 @@ impl<'a> CreateInvite<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Invite> {
         let mut request = Request::builder(&Route::CreateInvite {
-            channel_id: self.channel_id.0,
+            channel_id: self.channel_id.get(),
         });
 
         request = match request.json(&self.fields) {
@@ -298,7 +298,8 @@ mod tests {
     #[test]
     fn test_max_age() -> Result<(), Box<dyn Error>> {
         let client = Client::new("foo".to_owned());
-        let mut builder = CreateInvite::new(&client, ChannelId(1)).max_age(0)?;
+        let mut builder =
+            CreateInvite::new(&client, ChannelId::new(1).expect("non zero")).max_age(0)?;
         assert_eq!(Some(0), builder.fields.max_age);
         builder = builder.max_age(604_800)?;
         assert_eq!(Some(604_800), builder.fields.max_age);
@@ -310,7 +311,8 @@ mod tests {
     #[test]
     fn test_max_uses() -> Result<(), Box<dyn Error>> {
         let client = Client::new("foo".to_owned());
-        let mut builder = CreateInvite::new(&client, ChannelId(1)).max_uses(0)?;
+        let mut builder =
+            CreateInvite::new(&client, ChannelId::new(1).expect("non zero")).max_uses(0)?;
         assert_eq!(Some(0), builder.fields.max_uses);
         builder = builder.max_uses(100)?;
         assert_eq!(Some(100), builder.fields.max_uses);
