@@ -20,7 +20,7 @@ impl<'a> GetGuildPreview<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<GuildPreview> {
         let request = Request::from_route(&Route::GetGuildPreview {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
