@@ -6,7 +6,6 @@ use crate::{
 };
 use hyper::{client::ResponseFuture as HyperResponseFuture, StatusCode as HyperStatusCode};
 use std::{
-    convert::TryFrom,
     future::Future,
     marker::PhantomData,
     mem,
@@ -138,7 +137,12 @@ impl InFlight {
         }
 
         if let Some(tx) = self.tx {
-            match RatelimitHeaders::try_from(resp.headers()) {
+            let headers = resp
+                .headers()
+                .iter()
+                .map(|(key, value)| (key.as_str(), value.as_bytes()));
+
+            match RatelimitHeaders::from_pairs(headers) {
                 Ok(v) => {
                     let _res = tx.send(Some(v));
                 }
