@@ -204,6 +204,13 @@ impl Display for RouteDisplay<'_> {
 
                 Ok(())
             }
+            Route::CreateGuildSticker { guild_id, .. }
+            | Route::GetGuildStickers { guild_id, .. } => {
+                f.write_str("guilds/")?;
+                Display::fmt(guild_id, f)?;
+
+                f.write_str("/stickers")
+            }
             Route::CreateInvite { channel_id } | Route::GetChannelInvites { channel_id } => {
                 f.write_str("channels/")?;
                 Display::fmt(channel_id, f)?;
@@ -739,6 +746,27 @@ impl Display for RouteDisplay<'_> {
 
                 Ok(())
             }
+            Route::GetGuildSticker {
+                guild_id,
+                sticker_id,
+                ..
+            }
+            | Route::DeleteGuildSticker {
+                guild_id,
+                sticker_id,
+                ..
+            }
+            | Route::UpdateGuildSticker {
+                guild_id,
+                sticker_id,
+                ..
+            } => {
+                f.write_str("guilds/")?;
+                Display::fmt(guild_id, f)?;
+                f.write_str("/stickers/")?;
+
+                Display::fmt(sticker_id, f)
+            }
             Route::GetGuildVanityUrl { guild_id } => {
                 f.write_str("guilds/")?;
                 Display::fmt(guild_id, f)?;
@@ -856,6 +884,7 @@ impl Display for RouteDisplay<'_> {
 
                 Ok(())
             }
+            Route::GetNitroStickerPacks { .. } => f.write_str("sticker-packs"),
             Route::GetPins { channel_id } => {
                 f.write_str("channels/")?;
                 Display::fmt(channel_id, f)?;
@@ -952,6 +981,11 @@ impl Display for RouteDisplay<'_> {
 
                 Ok(())
             }
+            Route::GetSticker { sticker_id } => {
+                f.write_str("stickers/")?;
+
+                Display::fmt(sticker_id, f)
+            }
             Route::GetThreadMembers { channel_id } => {
                 f.write_str("channels/")?;
                 Display::fmt(channel_id, f)?;
